==> bsl-language-server-0.20.0-ra.2.jar: com/github/_1c_syntax/bsl/languageserver/diagnostics/ru/IncorrectLineBreak.md <==
# Неправильный перенос выражения (IncorrectLineBreak)

|      Тип      |    Поддерживаются<br>языки    |     Важность     |    Включена<br>по умолчанию    |    Время на<br>исправление (мин)    |               Теги                |
|:-------------:|:-----------------------------:|:----------------:|:------------------------------:|:-----------------------------------:|:---------------------------------:|
| `Дефект кода` |         `BSL`<br>`OS`         | `Информационный` |              `Да`              |                 `2`                 |    `standard`<br>`badpractice`    |

## Параметры


|             Имя              |   Тип    |                                                           Описание                                                           |    Значение<br>по умолчанию    |
|:----------------------------:|:--------:|:----------------------------------------------------------------------------------------------------------------------------:|:------------------------------:|
|      `checkFirstSymbol`      | `Булево` |                                      `Проверять начало строки на некорректные символы`                                       |             `true`             |
| `listOfIncorrectFirstSymbol` | `Строка` |   `Символы через вертикальную черту, с которых не должна начинаться строка (специальные символы должны быть экранированы)`   |          `\)|;|,|\);`          |
|      `checkLastSymbol`       | `Булево` |                                       `Проверять конец строки на некорректные символы`                                       |             `true`             |
| `listOfIncorrectLastSymbol`  | `Строка` | `Символы через вертикальную черту, на которые не должна заканчиваться строка (специальные символы должны быть экранированы)` |   `ИЛИ|И|OR|AND|\+|-|/|%|\*`   |
<!-- Блоки выше заполняются автоматически, не трогать -->
## Описание диагностики
<!-- Описание диагностики заполняется вручную. Необходимо понятным языком описать смысл и схему работу -->

Длинные арифметические выражения переносятся следующим образом:
в одной строке может находиться более одного операнда;
при переносе знаки операции пишутся в начале строки (а не в конце предыдущей строки);
операнды на новой строке предваряются стандартным отступом, либо выравниваются по началу первого операнда без учета знаков операций.

При необходимости параметры процедур, функций и методов следует переносить следующим образом:

* параметры выравниваются по началу первого параметра, либо предваряются стандартным отступом;
* закрывающая скобка и разделитель операторов ";" пишутся в той же строке, что и последний параметр;
* также допустим и способ форматирования, который предлагает функция автоформатирования в конфигураторе

Сложные логические условия в Если…ИначеЕсли…КонецЕсли следует переносить следующим образом:

* каждое элементарное условие нужно начинать с новой строки, если длина строки превышает ограничение в 120 символов;
* логические операторы И, ИЛИ ставятся в начале строки, а не в конце предыдущей строки;
* все условия предваряются стандартным отступом, либо выравниваются по началу первого условия, без учета логического оператора (для выравнивания выражений относительно первой строки рекомендуется использовать пробелы).

## Примеры
<!-- В данном разделе приводятся примеры, на которые диагностика срабатывает, а также можно привести пример, как можно исправить ситуацию -->

```bsl
СуммаДокумента = СуммаБезСкидки +
                 СуммаРучнойСкидки +
                 СуммаАвтоматическойСкидки;
```

## Источники
<!-- Необходимо указывать ссылки на все источники, из которых почерпнута информация для создания диагностики -->

* Источник: [Стандарт: Перенос выражений](https://its.1c.ru/db/v8std#content:444:hdoc)

## Сниппеты

<!-- Блоки ниже заполняются автоматически, не трогать -->
### Экранирование кода

```bsl
// BSLLS:IncorrectLineBreak-off
// BSLLS:IncorrectLineBreak-on
```

### Параметр конфигурационного файла

```json
"IncorrectLineBreak": {
    "checkFirstSymbol": true,
    "listOfIncorrectFirstSymbol": "\\)|;|,|\\);",
    "checkLastSymbol": true,
    "listOfIncorrectLastSymbol": "ИЛИ|И|OR|AND|\\+|-|/|%|\\*"
}
```

==> bsl-language-server-0.22.0.jar: com/github/_1c_syntax/bsl/languageserver/diagnostics/ru/IncorrectLineBreak.md <==
# Неправильный перенос выражения (IncorrectLineBreak)

|      Тип      |    Поддерживаются<br>языки    |     Важность     |    Включена<br>по умолчанию    |    Время на<br>исправление (мин)    |               Теги                |
|:-------------:|:-----------------------------:|:----------------:|:------------------------------:|:-----------------------------------:|:---------------------------------:|
| `Дефект кода` |         `BSL`<br>`OS`         | `Информационный` |              `Да`              |                 `2`                 |    `standard`<br>`badpractice`    |

## Параметры


|             Имя              |   Тип    |                                                           Описание                                                           |    Значение<br>по умолчанию    |
|:----------------------------:|:--------:|:----------------------------------------------------------------------------------------------------------------------------:|:------------------------------:|
|      `checkFirstSymbol`      | `Булево` |                                      `Проверять начало строки на некорректные символы`                                       |             `true`             |
| `listOfIncorrectFirstSymbol` | `Строка` |   `Символы через вертикальную черту, с которых не должна начинаться строка (специальные символы должны быть экранированы)`   |       `\)|;|,\s*\S+|\);`       |
|      `checkLastSymbol`       | `Булево` |                                       `Проверять конец строки на некорректные символы`                                       |             `true`             |
| `listOfIncorrectLastSymbol`  | `Строка` | `Символы через вертикальную черту, на которые не должна заканчиваться строка (специальные символы должны быть экранированы)` |   `ИЛИ|И|OR|AND|\+|-|/|%|\*`   |
<!-- Блоки выше заполняются автоматически, не трогать -->
## Описание диагностики
<!-- Описание диагностики заполняется вручную. Необходимо понятным языком описать смысл и схему работу -->

Длинные арифметические выражения переносятся следующим образом:
в одной строке может находиться более одного операнда;
при переносе знаки операции пишутся в начале строки (а не в конце предыдущей строки);
операнды на новой строке предваряются стандартным отступом, либо выравниваются по началу первого операнда без учета знаков операций.

При необходимости параметры процедур, функций и методов следует переносить следующим образом:

* параметры выравниваются по началу первого параметра, либо предваряются стандартным отступом;
* закрывающая скобка и разделитель операторов ";" пишутся в той же строке, что и последний параметр;
* также допустим и способ форматирования, который предлагает функция автоформатирования в конфигураторе

Сложные логические условия в Если…ИначеЕсли…КонецЕсли следует переносить следующим образом:

* каждое элементарное условие нужно начинать с новой строки, если длина строки превышает ограничение в 120 символов;
* логические операторы И, ИЛИ ставятся в начале строки, а не в конце предыдущей строки;
* все условия предваряются стандартным отступом, либо выравниваются по началу первого условия, без учета логического оператора (для выравнивания выражений относительно первой строки рекомендуется использовать пробелы).

**Примеры настройки исключений:**

- Если стандарт вашей команды требует, чтобы закрывающая скобка и разделитель операторов ";" были написаны *после* строки, на которой указан последний параметр, нужно исправить настройку параметра `listOfIncorrectFirstSymbol`
  - вместо подстроки `|\);` (в конце настройки) нужно написать подстроку `|\)\s*;\s*\S+`
  - пример финальной строки `\)|;|,\s*\S+|\)s*;\s*\S+`
  - пример кода указан в секции примеров

Без указанной настройки правило будет выдавать замечания на закрывающую скобка и разделитель операторов ";", если они на отдельной строке.

## Примеры
<!-- В данном разделе приводятся примеры, на которые диагностика срабатывает, а также можно привести пример, как можно исправить ситуацию -->

Неправильно:

```bsl
СуммаДокумента = СуммаБезСкидки +
                 СуммаРучнойСкидки +
                 СуммаАвтоматическойСкидки;
```

Правильно:

```bsl
СуммаДокумента = СуммаБезСкидки 
    + СуммаРучнойСкидки 
    + СуммаАвтоматическойСкидки;
```

или

```bsl
СуммаДокумента = СуммаБезСкидки 
                 + СуммаРучнойСкидки 
                 + СуммаАвтоматическойСкидки;
```

Пример возможного расположения параметров и закрывающей скобки с разделителем операторов ";"

```bsl
ИменаДокументов = Новый СписокЗначений;
ИменаДокументов.Добавить(Метаданные.Документы.СтрокаВыпискиРасход.Имя, 
                         Метаданные.Документы.СтрокаВыпискиРасход.Синоним);
```

Пример возможного расположения закрывающей скобки с разделителем операторов ";" на отдельной строке:
- без изменения параметра `listOfIncorrectFirstSymbol`, описанного выше, правило будет выдавать замечание на такой перенос выражений.

```bsl
ИменаДокументов = Новый СписокЗначений;
ИменаДокументов.Добавить(
    Метаданные.Документы.СтрокаВыпискиРасход.Имя, 
    Метаданные.Документы.СтрокаВыпискиРасход.Синоним
);
```

## Источники
<!-- Необходимо указывать ссылки на все источники, из которых почерпнута информация для создания диагностики -->

* Источник: [Стандарт: Перенос выражений](https://its.1c.ru/db/v8std#content:444:hdoc)

## Сниппеты

<!-- Блоки ниже заполняются автоматически, не трогать -->
### Экранирование кода

```bsl
// BSLLS:IncorrectLineBreak-off
// BSLLS:IncorrectLineBreak-on
```

### Параметр конфигурационного файла

```json
"IncorrectLineBreak": {
    "checkFirstSymbol": true,
    "listOfIncorrectFirstSymbol": "\\)|;|,\\s*\\S+|\\);",
    "checkLastSymbol": true,
    "listOfIncorrectLastSymbol": "ИЛИ|И|OR|AND|\\+|-|/|%|\\*"
}
```
